module.exports={A:{A:{"2":"K D E F A B 1C"},B:{"1":"OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I","2":"0 C L M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","194":"1","260":"2 3 4 5 6 7 8 JB KB LB MB NB"},C:{"1":"QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC 3C 4C","2":"0 1 2 3 4 5 6 7 8 9 2C WC J cB K D E F A B C L M G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB 5C 6C","260":"LB MB NB OB PB"},D:{"1":"OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC","2":"0 9 J cB K D E F A B C L M G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","194":"1","260":"2 3 4 5 6 7 8 JB KB LB MB NB"},E:{"1":"VC qC rC sC tC ID uC vC wC xC yC JD","2":"J cB K D E F A B C L M G 7C cC 8C 9C AD BD dC QC RC CD DD ED eC fC SC FD TC gC hC iC","260":"jC kC GD UC lC mC nC oC pC HD"},F:{"1":"0 1 2 3 4 5 6 7 8","2":"9 F B C G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m KD LD MD ND QC zC OD RC","194":"n o","260":"p q r s t u v w x y z"},G:{"1":"VC qC rC sC tC mD uC vC wC xC yC","2":"E cC PD 0C QD RD SD TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD eC fC SC jD TC gC hC iC","260":"jC kC kD UC lC mC nC oC pC lD"},H:{"2":"nD"},I:{"1":"I","2":"WC J oD pD qD rD 0C sD tD"},J:{"2":"D A"},K:{"2":"A B C QC zC RC","260":"H"},L:{"1":"I"},M:{"1":"PC"},N:{"2":"A B"},O:{"2":"SC"},P:{"2":"9 J AB BB CB DB uD vD wD xD yD dC zD 0D 1D 2D 3D TC UC VC 4D","260":"EB FB GB HB IB"},Q:{"2":"5D"},R:{"2":"6D"},S:{"2":"7D 8D"}},B:5,C:"CSS Relative color syntax",D:true};
