module.exports={A:{A:{"644":"K D E F 1C","772":"A B"},B:{"1":"0 1 2 3 4 5 6 7 8 P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I","260":"C L M G N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 J cB K D E F A B C L M G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC 3C 4C 5C 6C","8":"2C WC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 J cB K D E F A B C L M G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC"},E:{"1":"J cB K D E F A B C L M G 7C cC 8C 9C AD BD dC QC RC CD DD ED eC fC SC FD TC gC hC iC jC kC GD UC lC mC nC oC pC HD VC qC rC sC tC ID uC vC wC xC yC JD"},F:{"1":"0 1 2 3 4 5 6 7 8 9 C G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z RC","8":"F B KD LD MD ND QC zC OD"},G:{"1":"iD eC fC SC jD TC gC hC iC jC kC kD UC lC mC nC oC pC lD VC qC rC sC tC mD uC vC wC xC yC","2":"E cC PD 0C QD RD SD TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD"},H:{"2":"nD"},I:{"2":"WC J oD pD qD rD 0C sD tD","1025":"I"},J:{"2":"D A"},K:{"1":"RC","8":"A B C QC zC","1025":"H"},L:{"1025":"I"},M:{"2":"PC"},N:{"1":"A B"},O:{"1025":"SC"},P:{"2":"9 J AB BB CB DB EB FB GB HB IB uD vD wD xD yD dC zD 0D 1D 2D 3D TC UC VC 4D"},Q:{"1":"5D"},R:{"2":"6D"},S:{"2":"7D 8D"}},B:1,C:"Drag and Drop",D:true};
