module.exports={A:{A:{"1":"B","2":"K D E F A 1C"},B:{"2":"0 1 2 3 4 5 6 7 8 C L M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I"},C:{"1":"9 L M G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB","2":"0 1 2 3 4 5 6 7 8 2C WC J cB K D E F A B C zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC 3C 4C 5C 6C"},D:{"1":"9 J cB K D E F A B C L M G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB","2":"0 1 2 3 4 5 6 7 8 zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC"},E:{"1":"E F A B C BD dC QC","2":"J cB K D 7C cC 8C 9C AD","129":"L M G RC CD DD ED eC fC SC FD TC gC hC iC jC kC GD UC lC mC nC oC pC HD VC qC rC sC tC ID uC vC wC xC yC JD"},F:{"1":"9 G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB qB sB RC","2":"0 1 2 3 4 5 6 7 8 F B C oB pB rB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z KD LD MD ND QC zC OD"},G:{"1":"E TD UD VD WD XD YD ZD aD","2":"cC PD 0C QD RD SD","257":"bD cD dD eD fD gD hD iD eC fC SC jD TC gC hC iC jC kC kD UC lC mC nC oC pC lD VC qC rC sC tC mD uC vC wC xC yC"},H:{"2":"nD"},I:{"1":"WC J rD 0C sD tD","2":"I oD pD qD"},J:{"2":"D A"},K:{"1":"RC","2":"A B C H QC zC"},L:{"2":"I"},M:{"2":"PC"},N:{"1":"B","2":"A"},O:{"2":"SC"},P:{"1":"J","2":"9 AB BB CB DB EB FB GB HB IB uD vD wD xD yD dC zD 0D 1D 2D 3D TC UC VC 4D"},Q:{"2":"5D"},R:{"2":"6D"},S:{"1":"7D","2":"8D"}},B:7,C:"SPDY protocol",D:true};
