module.exports={A:{D:{"1":"TB UB VB WB XB YB ZB aB bB I aC PC bC","2":"J cB K D E F A B C L M G N","33":"0 1 2 3 4 5 6 7 8 9 O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB"},L:{"1":"I"},B:{"1":"TB UB VB WB XB YB ZB aB bB I","2":"C L M G N O P","33":"0 1 2 3 4 5 6 7 8 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB"},C:{"1":"0 1 2 3 4 5 6 7 8 g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC 3C 4C","2":"9 2C WC J cB K D E F A B C L M G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB 5C 6C","33":"wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f"},M:{"1":"PC"},A:{"2":"K D E F A B 1C"},F:{"1":"4 5 6 7 8","2":"F B C KD LD MD ND QC zC OD RC","33":"0 1 2 3 9 G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},K:{"2":"A B C QC zC RC","33":"H"},E:{"1":"fC SC FD TC gC hC iC jC kC GD UC lC mC nC oC pC HD VC qC rC sC tC ID uC vC wC xC yC","2":"J cB 7C cC 8C JD","33":"K D E F A B C L M G 9C AD BD dC QC RC CD DD ED eC"},G:{"1":"fC SC jD TC gC hC iC jC kC kD UC lC mC nC oC pC lD VC qC rC sC tC mD uC vC wC xC yC","2":"cC PD 0C QD","33":"E RD SD TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD eC"},P:{"1":"IB","33":"9 J AB BB CB DB EB FB GB HB uD vD wD xD yD dC zD 0D 1D 2D 3D TC UC VC 4D"},I:{"1":"I","2":"WC J oD pD qD rD 0C","33":"sD tD"}},B:6,C:"print-color-adjust property",D:undefined};
