module.exports={A:{A:{"2":"K D E F A B 1C"},B:{"1":"0 1 2 3 4 5 6 7 8 Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I","2":"C L M G N O P","1028":"W X","1540":"Q H R S T U V"},C:{"1":"0 1 2 3 4 5 6 7 8 CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC 3C 4C","2":"2C","164":"9 WC J cB K D E F A B C L M G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB 5C 6C","1540":"pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC"},D:{"1":"0 1 2 3 4 5 6 7 8 Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC","292":"9 J cB K D E F A B C L M G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC","1028":"W X","1540":"FC GC HC IC JC KC LC MC NC OC Q H R S T U V"},E:{"1":"G ED eC fC SC FD TC gC hC iC jC kC GD UC lC mC nC oC pC HD VC qC rC sC tC ID uC vC wC xC yC JD","292":"J cB K D E F A B C 7C cC 8C 9C AD BD dC QC","1540":"L M RC CD","3076":"DD"},F:{"1":"0 1 2 3 4 5 6 7 8 MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"F B C KD LD MD ND QC zC OD RC","292":"9 G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B","1028":"KC LC","1540":"4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC"},G:{"1":"iD eC fC SC jD TC gC hC iC jC kC kD UC lC mC nC oC pC lD VC qC rC sC tC mD uC vC wC xC yC","292":"E cC PD 0C QD RD SD TD UD VD WD XD YD ZD aD","1540":"bD cD dD eD fD gD","3076":"hD"},H:{"2":"nD"},I:{"1":"I","292":"WC J oD pD qD rD 0C sD tD"},J:{"292":"D A"},K:{"1":"H","2":"A B C QC zC RC"},L:{"1":"I"},M:{"1":"PC"},N:{"2":"A B"},O:{"1":"SC"},P:{"1":"9 AB BB CB DB EB FB GB HB IB 3D TC UC VC 4D","292":"J uD vD wD xD yD","1540":"dC zD 0D 1D 2D"},Q:{"1540":"5D"},R:{"1":"6D"},S:{"1":"8D","1540":"7D"}},B:5,C:"CSS Logical Properties",D:true};
