module.exports={A:{A:{"2":"K D E F A B 1C"},B:{"2":"C L M G N O P","2052":"0 1 2 3 4 5 6 7 8 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I"},C:{"2":"2C WC J cB 5C 6C","1028":"0 1 2 3 4 5 6 7 8 kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC 3C 4C","1060":"9 K D E F A B C L M G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB jB"},D:{"2":"9 J cB K D E F A B C L M G N O P dB AB BB CB DB EB","226":"FB GB HB IB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B","2052":"0 1 2 3 4 5 6 7 8 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC"},E:{"2":"J cB K D 7C cC 8C 9C","772":"L M G RC CD DD ED eC fC SC FD TC gC hC iC jC kC GD UC lC mC nC oC pC HD VC qC rC sC tC ID uC vC wC xC yC JD","804":"E F A B C BD dC QC","1316":"AD"},F:{"2":"9 F B C G N O P dB AB BB CB DB EB FB GB HB IB eB fB gB hB iB KD LD MD ND QC zC OD RC","226":"jB kB lB mB nB oB pB qB rB","2052":"0 1 2 3 4 5 6 7 8 sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"2":"cC PD 0C QD RD SD","292":"E TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD eC fC SC jD TC gC hC iC jC kC kD UC lC mC nC oC pC lD VC qC rC sC tC mD uC vC wC xC yC"},H:{"2":"nD"},I:{"1":"I","2":"WC J oD pD qD rD 0C sD tD"},J:{"2":"D A"},K:{"2":"A B C QC zC RC","2052":"H"},L:{"2052":"I"},M:{"1028":"PC"},N:{"2":"A B"},O:{"2052":"SC"},P:{"2":"J uD vD","2052":"9 AB BB CB DB EB FB GB HB IB wD xD yD dC zD 0D 1D 2D 3D TC UC VC 4D"},Q:{"2052":"5D"},R:{"2052":"6D"},S:{"1028":"7D 8D"}},B:4,C:"text-decoration styling",D:true};
